# Contributing to Nebari

Welcome 👋🏼!

Thanks for being interested in contributing to Nebari. We’re glad you want to join this community!
Open source doesn’t always have the best reputation for being friendly and welcoming, but the Nebari team truly believes
that everyone belongs in open source, and we are dedicated to making you feel welcome.

All contributions are welcome, including issues, contributing code, new docs as well as updates and tweaks, blog posts,
helping out people, organizing community events, working on accessibility and design items, and more.
Continue reading to learn what the community can do for you and what you can do for the community.
By contributing to open source projects you can connect with people, learn new skills, become a subject-matter expert,
and apply all learnings to your own projects.

> **Note**
> Our detailed contribution guidelines can be found [on Nebari's main documentation site][nebari-community].
> Make sure to check the guidelines before you start contributing.

## Reporting issues

When reporting issues please include as much detail as possible about your operating system, Nebari version, and dependencies version.
Whenever possible, also include a brief, self-contained code example that demonstrates the problem.
This [blog post by Matthew Rocklin](https://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports) is a good primer on how to craft minimal bug reports.

- Use the [Nebari issue tracker][nebari-issues] for issues, bug reports, and feature requests for Nebari.
- Use the [Nebari documentation issue tracker][nebari-docs-issues] for documentation-related improvements.
- Read more about [best practices for issues creation](https://www.nebari.dev/docs/community/file-issues) in our community docs.

<!-- Links -->

[nebari-docs-issues]: https://github.com/nebari-dev/nebari-docs/issues
[nebari-issues]: https://github.com/nebari-dev/nebari/issues
[nebari-community]: https://nebari.dev/docs/community
